/*
  Name:    Display.h
  Created: 01.06.2016
  Author:  Roman Schönfeld & Daniel Hausherr
*/

/***********************************************************************************************
  This work is licensed under a Creative Commons Attribution 4.0 International (CC BY 4.0) License.

  You are free to:

    Share — copy and redistribute the material in any medium or format
    Adapt — remix, transform, and build upon the material
    for any purpose, even commercially.

    The licensor cannot revoke these freedoms as long as you follow the license terms.

  Under the following terms:

    Attribution — You must give appropriate credit, provide a link to the license, and indicate if
    changes were made. You may do so in any reasonable manner, but not in any way that suggests
    the licensor endorses you or your use.

    No additional restrictions — You may not apply legal terms or technological measures that
    legally restrict others from doing anything the license permits.

  Credits:
        Laboratory for Physics and Illumination Technologies,
        University of Applied Sciences Southern Westfalia
        Germany

  Make Light! Support by the BMBF in the development of this device is gratefully acknowledged
***************************************************************************************************/
#ifndef _DISPLAY_h
#define _DISPLAY_h

#if defined(ARDUINO) && ARDUINO >= 100
#include "arduino.h"
#else
#include "WProgram.h"
#endif

#include <TFT.h>

/***************************************************************************************************
**  Define Constants
**
**  Define directives providing meaningful names for constant values.
***************************************************************************************************/
#define _DC           5
#define _CS           3
#define _BL           9
#define _RES          6

#define _TFT_BRIGHTNESS 255
#define _RESET LOW
#define _NRESET HIGH
#define _POINTER "->"


/***************************************************************************************************
**  init_tft
**
**  Initialisiert das Display
**
**  Input:  None
**  Output: None
***************************************************************************************************/
extern void init_tft();

/***************************************************************************************************
**  set_brightness_tft
**
**  Zum verändern der Helligkeit des Displays
**
**  Input:  pwr Byte Werte zwischen 0 - 255
**  Output: None
***************************************************************************************************/
extern void set_brightness_tft(uint8_t light);

/***************************************************************************************************
**  print_text_tft
**
**  Gibt Text auf dem Display aus
**
**  Input: text, color Farbe der Textzeichen 
**  Output: None
***************************************************************************************************/
extern void print_text_tft(char *text, uint16_t color);

/***************************************************************************************************
**  print_value_tft
**
**  Gibt Werte auf dem Display aus
**
**  Input: value, color Farbe der Zeichen
**  Output: None
***************************************************************************************************/
extern void print_value_tft(uint16_t value, uint16_t color);

/***************************************************************************************************
**  print_value_tft_double
**
**  Gibt Fließkommawerte auf dem Display aus
**
**  Input: value, color Farbe der Zeichen
**  Output: None
***************************************************************************************************/
extern void print_value_tft_double(double value, uint16_t color);

/***************************************************************************************************
**  set_cursor_tft
**
**  Setzt den Kurser auf die Koordinanten x und y
**
**  Input:  x - Achse und y - Achse
**  Output: None
***************************************************************************************************/
extern void set_cursor_tft(uint8_t x, uint8_t y);

/***************************************************************************************************
**  set_text_size_tft
**
**  Bestimmt die Größe der Zeichen
**
**  Input: text_size 
**  Output: None
***************************************************************************************************/
extern void set_text_size_tft(uint8_t text_size);

/***************************************************************************************************
**  clear_area_tft
**
** Bestimmt die Fläche (Rechteck) des Displays, die überzeichnet werden soll
**
**  Input: x,y Koordinate und size_x, size_y Länge, color Farbe des Rechtecks
**  Output: None
***************************************************************************************************/
extern void clear_area_tft(uint8_t x, uint8_t y, uint8_t size_x, uint8_t size_y, uint16_t color);

#endif
